==> cod-tools_2.1+dfsg.orig.tar.gz: cod-tools-2.1/src/lib/perl5/COD/CIF/Tags/COD.pm <==
#------------------------------------------------------------------------
#$Author: antanas $
#$Date: 2015-11-08 10:28:29 +0200 (Sun, 08 Nov 2015) $ 
#$Revision: 4227 $
#$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/lib/perl5/COD/CIF/Tags/COD.pm $
#------------------------------------------------------------------------
#* 
#  A list of CIF dictionary tags.
#**

package COD::CIF::Tags::COD;

use strict;
use warnings;

require Exporter;
our @ISA = qw( Exporter );
our @EXPORT_OK = qw(
    @tag_list
);

our @tag_list = qw (
_[local]_cod_duplicate_entry
_[local]_cod_superseeded_by
_[local]_cod_data_source_file
_[local]_cod_data_source_block
_[local]_cod_published_source
_[local]_cod_data_source_MD5_sum
_[local]_cod_data_source_SHA1_sum
_[local]_cod_data_source_SHA256_sum
_[local]_cod_est_spacegroup_name_H-M
_[local]_cod_depositor_comments
_[local]_cod_error_flag
_[local]_cod_error_source
_[local]_cod_error_description
_[local]_cod_cif_authors_sg_H-M
_[local]_cod_cif_authors_sg_Hall
_[local]_cod_cif_authors_sg_number
_[local]_cod_original_cell_volume
_[local]_cod_suboptimal_structure
_[local]_cod_related_optimal_struct
_[local]_cod_related_suboptimal_struct
_[local]_cod_chemical_formula_sum_orig
_[local]_cod_chemical_formula_moiety_orig
_[local]_cod_citation_special_details
_[local]_cod_text

_cod_enantiomer_of
_cod_duplicate_entry
_cod_superseeded_by
_cod_data_source_file
_cod_data_source_block
_cod_published_source
_cod_data_source_MD5_sum
_cod_data_source_SHA1_sum
_cod_data_source_SHA256_sum
_cod_est_spacegroup_name_H-M
_cod_depositor_comments
_cod_error_flag
_cod_error_source
_cod_error_description
_cod_cif_authors_sg_H-M
_cod_cif_authors_sg_Hall
_cod_cif_authors_sg_number
_cod_original_cell_volume
_cod_original_sg_number
_cod_original_sg_symbol_Hall
_cod_original_sg_symbol_H-M
_cod_original_formula_moiety
_cod_original_formula_sum
_cod_original_formula_units_Z
_cod_original_formula_weight
_cod_same_crystal_as
_cod_struct_determination_method
_cod_suboptimal_structure
_cod_related_optimal_struct
_cod_related_suboptimal_struct
_cod_related_entry
_cod_related_entry_database
_cod_related_entry_description
_cod_chemical_formula_sum_orig
_cod_chemical_formula_moiety_orig
_cod_citation_special_details
_cod_text
_cod_database_code
_cod_database_fobs_code
_cod_hold_until_date
);

1;

==> cod-tools_2.2+dfsg.orig.tar.gz: cod-tools-2.2/src/lib/perl5/COD/CIF/Tags/COD.pm <==
#------------------------------------------------------------------------
#$Author: antanas $
#$Date: 2017-10-13 11:23:02 +0300 (Fri, 13 Oct 2017) $ 
#$Revision: 5614 $
#$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/lib/perl5/COD/CIF/Tags/COD.pm $
#------------------------------------------------------------------------
#* 
#  A list of CIF dictionary tags.
#**

package COD::CIF::Tags::COD;

use strict;
use warnings;

require Exporter;
our @ISA = qw( Exporter );
our @EXPORT_OK = qw(
    @tag_list
);

our @tag_list = qw (
_[local]_cod_duplicate_entry
_[local]_cod_superseeded_by
_[local]_cod_data_source_file
_[local]_cod_data_source_block
_[local]_cod_published_source
_[local]_cod_data_source_MD5_sum
_[local]_cod_data_source_SHA1_sum
_[local]_cod_data_source_SHA256_sum
_[local]_cod_est_spacegroup_name_H-M
_[local]_cod_depositor_comments
_[local]_cod_error_flag
_[local]_cod_error_source
_[local]_cod_error_description
_[local]_cod_cif_authors_sg_H-M
_[local]_cod_cif_authors_sg_Hall
_[local]_cod_cif_authors_sg_number
_[local]_cod_original_cell_volume
_[local]_cod_suboptimal_structure
_[local]_cod_related_optimal_struct
_[local]_cod_related_suboptimal_struct
_[local]_cod_chemical_formula_sum_orig
_[local]_cod_chemical_formula_moiety_orig
_[local]_cod_citation_special_details
_[local]_cod_text

_cod_enantiomer_of
_cod_duplicate_entry
_cod_superseeded_by
_cod_data_source_file
_cod_data_source_block
_cod_data_source_URI
_cod_data_source_URL
_cod_data_source_URN
_cod_data_source_MD5_sum
_cod_data_source_SHA1_sum
_cod_data_source_SHA256_sum
_cod_published_source
_cod_est_spacegroup_name_H-M
_cod_depositor_comments
_cod_error_flag
_cod_error_source
_cod_error_description
_cod_cif_authors_sg_H-M
_cod_cif_authors_sg_Hall
_cod_cif_authors_sg_number
_cod_original_cell_volume
_cod_original_sg_number
_cod_original_sg_symbol_Hall
_cod_original_sg_symbol_H-M
_cod_original_formula_moiety
_cod_original_formula_iupac
_cod_original_formula_sum
_cod_original_formula_units_Z
_cod_original_formula_weight
_cod_same_crystal_as
_cod_struct_determination_method
_cod_suboptimal_structure
_cod_related_optimal_struct
_cod_related_suboptimal_struct
_cod_related_entry
_cod_related_entry_id
_cod_related_entry_code
_cod_related_entry_database
_cod_related_entry_description
_cod_related_entry_uri
_cod_chemical_formula_sum_orig
_cod_chemical_formula_moiety_orig
_cod_citation_special_details
_cod_text
_cod_database_code
_cod_database_fobs_code
_cod_database_coordinates_code
_cod_hold_until_date
);

1;
